@@ -398,13 +398,13 @@ int readcg(char *name)
 	char	*r;
 	FILE* fd = fopen(name, "r");
 	if (fd == NULL) {
-		fprintf(stderr, "can't open %s \n", name);
+		// fprintf(stderr, "can't open %s \n", name);
 		return 0;
 	}
 
 	r = fgets(readcg_buf, MAXGETLINE-1, fd);
 	if (r == NULL) {
-		fprintf(stderr, "can't read value : %s\n", name);
+		// fprintf(stderr, "can't read value : %s\n", name);
 		fclose(fd);
 		return 0;
 	}
@@ -656,42 +656,35 @@ int show(FILE* fd, char *name)
 	}
 	buf[1024-1] = 0;
 
-	if (!readcg(buf)) {
-		return -1;
+	if (readcg(buf)) {
+		fprintf(fd, "\"cpun\" : \"%s\", ", readcg_buf);
+		fprintf(fd, "\n ");
 	}
-
-	fprintf(fd, "\"cpun\" : \"%s\", ", readcg_buf);
-
-	fprintf(fd, "\n ");
-
+	
 	/* get a cpu.cfs_period_us */	
 	snprintf(buf, 1024-1, CPU_CFS_PERIOD_US, NAME1, NAME2);
 	buf[1024-1] = 0;
 
-	if (!readcg(buf)) {
-		return -1;
+	if (readcg(buf)) {
+		/* display cpu rate */
+		cpuperiod = strtol(readcg_buf, NULL, 10);
 	}
-
-	/* display cpu rate */
-	cpuperiod = strtol(readcg_buf, NULL, 10);
-
+	
 	snprintf(buf, 1024-1, CPU_CFS_QUOTA_US,	NAME1, NAME2);
 	buf[1024-1] = 0;
 
-	if (!readcg(buf)) {
-		return -1;
-	}
+	if (readcg(buf)) {
+		cpuquota = strtol(readcg_buf, NULL, 10);
+		if (cpuquota < 0) {
+			fprintf(fd, "\"cpurate\" : \"-\", ");
+		} else {
+			cpurate = cpuquota*100 / cpuperiod;
+			fprintf(fd, "\"cpurate\" : \"%ld\", ", cpurate);
+		}
 
-	cpuquota = strtol(readcg_buf, NULL, 10);
-	if (cpuquota < 0) {
-		fprintf(fd, "\"cpurate\" : \"-\", ");
-	} else {
-		cpurate = cpuquota*100 / cpuperiod;
-		fprintf(fd, "\"cpurate\" : \"%ld\", ", cpurate);
+		fprintf(fd, "\n ");
 	}
 
-	fprintf(fd, "\n ");
-
 	/* display numa */
 	if (libvirtname == LXCNAME) {
 		snprintf(buf, 1024-1, CPUSET_MEMS, NAME1, NAME2);
@@ -700,42 +693,35 @@ int show(FILE* fd, char *name)
 	}
 	buf[1024-1] = 0;
 
-	if (!readcg(buf)) {
-		return -1;
+	if (readcg(buf)) {
+		fprintf(fd, "\"numa\" : \"%s\", ", readcg_buf);
+		fprintf(fd, "\n ");
 	}
-
-	fprintf(fd, "\"numa\" : \"%s\", ", readcg_buf);
-
-	fprintf(fd, "\n ");
-
+	
 	/* display memory limit */
 	snprintf(buf, 1024-1, MEMORY_LIMIT_IN_BYTES, NAME1, NAME2);
 	buf[1024-1] = 0;
 	
-	if (!readcg(buf)) {
-		return -1;
+	if (readcg(buf)) {
+		fprintf(fd, "\"memlimit\" : \"");
+		printKMG(fd, readcg_buf);
+		fprintf(fd, "\", ");
+
+		fprintf(fd, "\n");
 	}
-
-	fprintf(fd, "\"memlimit\" : \"");
-	printKMG(fd, readcg_buf);
-	fprintf(fd, "\", ");
-
-	fprintf(fd, "\n ");
-
+	
 	/* display memory+swap limit */
 	snprintf(buf, 1024-1, MEMORY_MEMSW_LIMIT_IN_BYTES, NAME1, NAME2);
 	buf[1024-1] = 0;
 	
-	if (!readcg(buf)) {
-		return -1;
+	if (readcg(buf)) {
+		fprintf(fd, " \"memswlimit\" : \"");
+		printKMG(fd, readcg_buf);
+		fprintf(fd, "\", ");
+
+		fprintf(fd, "\n");
 	}
-
-	fprintf(fd, "\"memswlimit\" : \"");
-	printKMG(fd, readcg_buf);
-	fprintf(fd, "\", ");
-
-	fprintf(fd, "\n");
-
+	
 	show_blkio(fd, name);
 
 	fprintf(fd, " ");
@@ -810,16 +796,12 @@ int show_net_cls(FILE* fd, char *name)
 
 	buf[1024-1] = 0;
 
-	if (!readcg(buf)) {
-		return -1;
+	if (readcg(buf)) {
+		net_cls = strtol(readcg_buf, NULL, 10);
+		fprintf(fd, "\"net_cls\" : \"%08lx\" ", net_cls);
 	}
 
-	net_cls = strtol(readcg_buf, NULL, 10);
-	
-	fprintf(fd, "\"net_cls\" : \"%08lx\" ", net_cls);
-
 	fprintf(fd, "}\n");
-
 	return 1;
 }
 
