@@ -177,7 +177,7 @@ void clear_exec_job(char *filename, pid_t pid)
 	char buf[4096];
 
 	snprintf(buf, 4096 - 1,
-			"/usr/bin/flock %s /usr/bin/sed -i \"/^%010d/d\" %s",
+			"/usr/bin/flock %s /bin/sed -i \"/^%010d/d\" %s",
 			filename, pid, filename);
 	buf[4096 - 1] = 0;
 	if (system(buf) == -1) {
@@ -188,7 +188,7 @@ void clear_exec_job(char *filename, pid_t pid)
 // exec of a job
 void lxcf_ex(char *arg)
 {
-	execlp("/bin/sh", "sh", "-c", arg, NULL);
+	execlp("/bin/bash", "bash", "-c", arg, NULL);
 	fprintf(stderr, "error: exec %s\n", arg);
 	exit(-1);
 }
